.. admonition:: title
                a
              b

   a
    b

.. attention::
  a

  - a

    #.   x

.. caution::
 c

.. danger::
        d

.. error::
    e

.. hint::
      h

.. important::
  i

.. note::
         n

.. tip::
    t

.. warning::
     w
     x
     y
